@@ -4,11 +4,16 @@ by specified edge labels mapping.
 from typing import Any, Dict
 
 from networkx import MultiDiGraph
+from tqdm import tqdm
 
 __all__ = ["change_edges"]
 
 
-def change_edges(graph: MultiDiGraph, spec: Dict[str, Any]) -> MultiDiGraph:
+def change_edges(
+    graph: MultiDiGraph,
+    spec: Dict[str, Any],
+    verbose: bool = True,
+) -> MultiDiGraph:
     """Returns a graph with relabeled edges
     by specified edge labels mapping.
 
@@ -20,15 +25,18 @@ def change_edges(graph: MultiDiGraph, spec: Dict[str, Any]) -> MultiDiGraph:
     spec: Dict
         Edge labels mapping.
 
+    verbose : bool
+        If true, a progress bar will be displayed.
+
     Examples
     --------
     >>> import cfpq_data
-    >>> g = cfpq_data.labeled_cycle_graph(42)
-    >>> new_g = cfpq_data.change_edges(g, {"a": "b"})
-    >>> g.number_of_nodes() == new_g.number_of_nodes()
-    True
-    >>> g.number_of_edges() == new_g.number_of_edges()
-    True
+    >>> g = cfpq_data.labeled_cycle_graph(42, edge_label="a", verbose=False)
+    >>> new_g = cfpq_data.change_edges(g, {"a": "b"}, verbose=False)
+    >>> new_g.number_of_nodes()
+    42
+    >>> new_g.number_of_edges()
+    42
 
     Returns
     -------
@@ -40,11 +48,13 @@ def change_edges(graph: MultiDiGraph, spec: Dict[str, Any]) -> MultiDiGraph:
     for node, node_labels in graph.nodes(data=True):
         g.add_node(node, **node_labels)
 
-    for u, v, edge_labels in graph.edges(data=True):
+    for u, v, edge_labels in tqdm(
+        graph.edges(data=True), disable=not verbose, desc="Generation..."
+    ):
         changed_edge_labels = dict()
         for key, value in edge_labels.items():
             if str(value) in spec.keys():
-                changed_edge_labels[key] = spec[value]
+                changed_edge_labels[key] = spec[str(value)]
             else:
                 changed_edge_labels[key] = value
         g.add_edge(u, v, **changed_edge_labels)
